Annotations
===========

.. automodule:: ngsidekick.annotations
   :members:
   :undoc-members:
   :show-inheritance:

Overview
--------

The annotations module provides tools for working with Neuroglancer annotations.

Submodules
----------

.. toctree::
   :maxdepth: 1

   local
   precomputed

